Modules
- decision
- The
decisionis a specified object format for Shisho Cloud and has to be returned. - gqlgen
- The
gqlgenincludes the functionalities of converting fromgeraphqlschema and queries to Rust structs - language
- The
languageis the set of helper methods and structs - schema
schemaincludes the string of graphql query of Shisho Cloud. The schema is generated by the codegen.